<template>
  <el-dialog
    :title="title"
    :visible.sync="dialogVisible"
    :modal-append-to-body="false"
    :close-on-click-modal="false"
    width="50%"
    :before-close="handleClose"
  >
    <el-form ref="dataForm" :model="dataForm"  :rules="rules" label-position="right" label-width="150px" style="padding-right: 50px" element-loading-text="保存中...">
      <el-form-item label="所属区划:" prop="districtCode">
        <el-select v-model="dataForm.districtCode" style="margin-left: 15px" :disabled="!isShow" placeholder="行政区划">
          <el-option
            v-for="item in areaList"
            :key="item.id"
            :label="item.name"
            :value="item.code">
          </el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="类别:" prop="categoryType">
        <el-radio-group v-model="dataForm.categoryType">
          <el-radio :label="1">理论</el-radio>
          <el-radio :label="2">实操</el-radio>
        </el-radio-group>
      </el-form-item>
      <el-form-item label="科目名称:" prop="subjectName">
        <el-input v-model.trim="dataForm.subjectName"/>
      </el-form-item>
      <el-form-item label="资格类型:">
        <el-cascader
          v-model="dataForm.operateTypeId"
          :options="typeList"
          style="width: 100%"
          :props="{ expandTrigger: 'hover', value: 'id',label: 'name',emitPath: false, checkStrictly: true}"></el-cascader>
      </el-form-item>
      <el-form-item label="金额:" prop="amount">
        <el-input v-model.trim.number="dataForm.amount">
          <template #append>元</template>
        </el-input>
      </el-form-item>
      <el-form-item label="业务代码:" prop="businessCode">
        <el-input v-model.trim="dataForm.businessCode"/>
      </el-form-item>
      <el-form-item label="单位编码:" prop="companyCode">
        <el-input v-model.trim="dataForm.companyCode"/>
      </el-form-item>
      <el-form-item label="开票人:" prop="drawer">
        <el-input v-model.trim="dataForm.drawer"/>
      </el-form-item>
      <el-form-item label="复核人:" prop="reviewer">
        <el-input v-model.trim="dataForm.reviewer"/>
      </el-form-item>
      <el-form-item label="开票单位社会信用代码:" prop="invoicingCompanyCode">
        <el-input v-model.trim="dataForm.invoicingCompanyCode"/>
      </el-form-item>
      <el-form-item label="描述:" prop="describe">
        <el-input v-model.trim="dataForm.describe"/>
      </el-form-item>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="handleClose">取 消</el-button>
      <el-button type="primary" @click="onSubmit">确 定</el-button>
    </span>
  </el-dialog>
</template>

<script >
import { addPlat, updatePlat } from '@/api/onlineEducation/plat'
import { verifySimplePhone } from '@/utils/validate'
import {getAreaList} from "@/api/coalMine/placeManage/train";
import {getOperatePage} from "@/api/coalMine/operateType";
import {addNotCoalPayCategory, getNotCoalPayCategory, updateNotCoalPayCategory} from "@/api/specialOperationsPay/notCoalPay";
import store from "@/store";

export default {
  name: 'detailDialog',
  components: {
  },
  data() {
    return {
      dialogVisible: false,
      title: '',
      areaList: [],
      typeList: [],
      rules: {
        districtCode: [{ required: true, message: '请选择所属区划', trigger: 'blur' }],
        categoryType: [{ required: true, message: '请选择类别', trigger: 'blur' }],
        subjectName: [{ required: true, message: '请输入科目名称', trigger: 'blur' }],
        amount: [{ required: true, message: '请输入金额', trigger: 'blur' }],
        businessCode: [{ required: true, message: '请输入业务代码', trigger: 'blur' }],
        companyCode: [{ required: true, message: '请输入单位编码', trigger: 'blur' }],
        drawer: [{ required: true, message: '请输入开票人', trigger: 'blur' }],
        reviewer: [{ required: true, message: '请输入复核人', trigger: 'blur' }],
        invoicingCompanyCode: [{ required: true, message: '请输入开票单位社会信用代码', trigger: 'blur' }]
      },
      dataForm: {

      },
      isShow: false
    }
  },
  created() {

  },
  methods: {
    openDialog (type, data, areaList,code) {
      this.resetDataForm()
      this.areaList = areaList
      if(code !== '65'){
        this.dataForm.districtCode = code
        this.isShow = false
      }else{
        this.isShow = true
      }
      this.getTypeList()
      this.dialogVisible = true
      this.title = type == 'add'?'新增':'编辑'
      if(this.title == '编辑') {
        console.log(data,'data')
        this.dataForm = data
      }
      this.$nextTick(() => {
        this.$refs['dataForm'].clearValidate()
      })
    },
    // async getArea() {
    //   const res = await getAreaList();
    //   if (res.code == 200) {
    //     this.areaList = res.data
    //   }
    // },
    async getTypeList() {
      this.loading = true;
      const res = await getOperatePage({name: ''})
      if(res.code == 200){
        this.typeList = this.handleTree(res.data, "id");
      }else{
        this.$message({
          type: 'warning',
          message: res.msg
        });
      }
      this.loading = false;
    },
    handleClose() {
      this.dialogVisible = false;
      this.$emit("getList");
    },
    onSubmit() {
      this.$refs["dataForm"].validate( async valid => {
        if (valid) {
          if(this.title == '新增'){
            console.log("this.dataForm",this.dataForm)
            const res = await addNotCoalPayCategory(this.dataForm);
            if(res.code == 200) {
              this.$emit("getList");
              this.dialogVisible = false;
              this.$message({
                type:'success',
                message: '新增成功'
              })
            }else{
              this.$message({
                type:'warning',
                message: res.msg
              })
            }
          }else {
            const res = await updateNotCoalPayCategory(this.dataForm);
            if(res.code == 200) {
              this.$emit("getList");
              this.dialogVisible = false;
              this.$message({
                type:'success',
                message: '编辑成功'
              })
            }else{
              this.$message({
                type:'warning',
                message: res.msg
              })
            }
          }
        }
      })

    },
    resetDataForm() {
      this.dataForm = {
      }
    },
  }
}

</script>
<style scoped>
.infoTitle{
  margin-top:-10px;
  margin-bottom:20px;
  display: flex;
  justify-content: space-around;
  font-weight: 800;
  font-size: 16px
}

</style>
